#!/usr/bin/env bash
#
# Deploy a built conda package to a FSL conda channel. See
# fsl-ci-conda-rules.yml.
#
# Deploying a built conda package is simply a matter of copying the
# built packages into the channel directory and running "conda index".

pkgdir=./conda_build

if [ "$STAGING" == "true" ]; then
  channel_dir=$FSLCONDA_STAGING_CHANNEL_DIRECTORY
else
  channel_dir=$FSLCONDA_PRODUCTION_CHANNEL_DIRECTORY
fi

echo "************************************"
echo "Deploying built conda package for:       $CI_PROJECT_NAME"
echo "Recipe URL:                              $CI_PROJECT_URL"
echo "Project revision (empty means to "
echo "  build release specified in meta.yaml): $PROJECT_REF"
echo "FSL conda channel:                       $channel_dir"
echo "************************************"

# copy all package files from the conda-build
# output directory into the conda channel directory

# the build_conda_package.py script stores its
# outputs in a platform-specific subdirectory -
# one of _linux_, _macos_, or _noarch_
for fslplat in _linux_ _macos_ _noarch_ ; do

  # within each one of those is a conventional
  # conda channel structure - copy any package
  # files that we find into the output channel
  # directory.
  for condaplat in noarch linux-64 osx-64 win-32 win64; do
    if ls $pkgdir/$fslplat/$condaplat/*.tar.bz2 &> /dev/null; then

      ls -l $pkgdir/$fslplat/$condaplat/*.tar.bz2

      mkdir -p $channel_dir/$condaplat
      cp $pkgdir/$fslplat/$condaplat/*.tar.bz2 $channel_dir/$condaplat

    fi
  done
done

# The conda index command doesn't seem to
# reliably refresh information about newly
# added packages, so we delete the old index
# metadata before running it.
find . -name "*.html"     -delete
find . -name "*.json"     -delete
find . -name "*.json.bz2" -delete

# re-generate the channel index
conda index $channel_dir
